#
# spec file for package maven-surefire-provider-junit5
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_name maven-surefire
Name:           %{base_name}-provider-junit5
Version:        2.22.2
Release:        1.2
Summary:        JUnit 5 provider for Maven Surefire
License:        Apache-2.0 AND CPL-1.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/surefire/
Source0:        %{base_name}-%{version}.tar.xz
Source1:        https://www.apache.org/licenses/LICENSE-2.0.txt
Source2:        https://www.eclipse.org/legal/cpl-v10.html
Patch0:         0001-Maven-3.patch
Patch1:         0002-Port-to-current-doxia.patch
Patch2:         0003-Port-to-TestNG-7.4.0.patch
Patch3:         0004-Port-to-current-maven-shared-utils.patch
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.maven.surefire:common-java5)
BuildRequires:  mvn(org.apache.maven:maven-parent:pom:)
BuildRequires:  mvn(org.apiguardian:apiguardian-api)
BuildRequires:  mvn(org.junit.platform:junit-platform-launcher)
# PpidChecker relies on /usr/bin/ps to check process uptime
Requires:       procps
BuildArch:      noarch

%description
JUnit 5 provider for Maven Surefire.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n %{base_name}-%{version}
cp -p %{SOURCE1} %{SOURCE2} .

%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1

# Disable strict doclint
sed -i /-Xdoclint:all/d pom.xml

%pom_disable_module surefire-shadefire

%pom_add_dep org.apiguardian:apiguardian-api::provided surefire-providers/surefire-junit-platform

%pom_remove_dep -r org.apache.maven.surefire:surefire-shadefire

# QA plugin useful only for upstream
%pom_remove_plugin -r :jacoco-maven-plugin

# Not in Fedora
%pom_remove_plugin -r :animal-sniffer-maven-plugin
# Complains
%pom_remove_plugin -r :apache-rat-plugin
%pom_remove_plugin -r :maven-enforcer-plugin
# We don't need site-source
%pom_remove_plugin :maven-assembly-plugin maven-surefire-plugin
%pom_remove_dep -r ::::site-source

%pom_xpath_set pom:mavenVersion 3.3.3
%pom_remove_dep :maven-project maven-surefire-report-plugin
%pom_remove_dep :maven-project maven-surefire-common
%pom_remove_dep :maven-plugin-descriptor maven-surefire-common
%pom_remove_dep :maven-toolchain maven-surefire-common

%pom_xpath_remove -r "pom:execution[pom:id='shared-logging-generated-sources']"

%pom_add_dep com.google.code.findbugs:jsr305 surefire-api

%pom_remove_plugin -r :maven-shade-plugin
%pom_remove_plugin -r :build-helper-maven-plugin

%pom_add_dep org.apache.commons:commons-lang3::runtime maven-surefire-plugin
%pom_add_dep commons-io:commons-io::runtime maven-surefire-plugin

%build
pushd surefire-providers/surefire-junit-platform
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

popd

%install
pushd surefire-providers/surefire-junit-platform
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}
popd

%files -f surefire-providers/surefire-junit-platform/.mfiles
%doc README.md
%license LICENSE-2.0.txt cpl-v10.html

%files javadoc -f surefire-providers/surefire-junit-platform/.mfiles-javadoc
%license LICENSE-2.0.txt cpl-v10.html

%changelog
* Thu Feb 22 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to 2.22.2
  * Bugs:
    + SUREFIRE-1614: JUnit Runner that writes to System.out
    corrupts Surefire’s STDOUT when using JUnit’s Vintage Engine
- Upgrade to 2.22.1
  * Bugs:
    + SUREFIRE-1532: MIME type for javascript is now officially
    application/javascript
    + SUREFIRE-1535: Surefire unable to run testng suites in
    parallel
    + SUREFIRE-1538: Git considers PNG files as changed although
    there is no change
    + SUREFIRE-1550: The surefire XSD published on maven site lacks
    of some rerun element
    + SUREFIRE-1559: XML Report elements rerunError, rerunFailure,
    flakyFailure, flakyError should contain element stackTrace and
    should not be simpleContent.
    + SUREFIRE-1561: Logs in Parallel Tests are mixed up when
    forkMode=never or forkCount=0
    + SUREFIRE-1564: Can’t override platform version through
    project/plugin dependencies
    + SUREFIRE-1579: Forks mixed up characters in standard output
  * Improvements:
    + SUREFIRE-1552: Nil element “failureMessage” in
    failsafe-summary.xml should have self closed tag
    + SUREFIRE-1554: Fix old test resources TEST-*.xml in favor of
    continuing with SUREFIRE-1550
    + SUREFIRE-1555: Elapsed time in XML Report should satisfy
    pattern in XSD.
    + SUREFIRE-1562: Support Java 11
    + SUREFIRE-1565: Surefire should support parameterized
    reportsDirectory
  * Tasks:
    + SUREFIRE-1569: m-invoker-p:3.1.0 attempts to resolve
    maven-surefire-common:jar:2.22.1-SNAPSHOT from remote repo
    'apache.snapshots'
    + SUREFIRE-1578: Remove obsolete module
    surefire-setup-integration-tests
  * Dependency upgrades:
    + SUREFIRE-1540: Upgrade maven-plugins parent to version 32
    + SUREFIRE-1571: Upgrade maven-plugins parent to version 33
- Fetch sources using source service to avoid bundling binaries in
  sources
- Fix broken links in the spec file
- Modified patch:
  * 0004-Port-to-current-maven-shared-utils.patch
    + rediff to changed context
* Wed Apr 27 2022 Fridrich Strba <fstrba@suse.com>
- Modified patches:
  * 0004-Port-to-current-maven-shared-utils.patch
    + Add some try/catch blocks so that we catch new exceptions
    potentially thrown by maven-shared-utils-3.3.x
  * 0003-Port-to-TestNG-6.11.patch -> 0003-Port-to-TestNG-7.4.0.patch
    + Allow building with the new testng 7.4.0
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Mon Apr 19 2021 Pedro Monreal <pmonreal@suse.com>
- Update generate-tarball.sh to use https URL [bsc#1182708]
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Mon Jul  1 2019 Fridrich Strba <fstrba@suse.com>
- Intial packaging of junit 5 provider for maven surefire
